# mcp-kubernetes-server

MCP server to manage Kubernetes clusters via kubectl.

## How to install

```json
{
  "mcpServers": {
    "kubernetes": {
      "command": "uvx",
      "args": [
        "mcp-kubernetes-server"
      ]
    }
  }
}
```
